==> jalview_2_05b.tar.gz: jalview/src/jalview/gui/Desktop.java <==
/*
 * Jalview - A Sequence Alignment Editor and Viewer
 * Copyright (C) 2005 AM Waterhouse, J Procter, G Barton, M Clamp, S Searle
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package jalview.gui;

import jalview.io.*;

import java.awt.*;
import java.awt.datatransfer.*;
import java.awt.dnd.*;
import java.awt.event.*;

import javax.swing.*;


/**
 * DOCUMENT ME!
 *
 * @author $author$
 * @version $Revision: 1.63 $
 */
public class Desktop extends jalview.jbgui.GDesktop
    implements DropTargetListener
{
    /** DOCUMENT ME!! */
    public static JDesktopPane desktop;
    static int openFrameCount = 0;
    static final int xOffset = 30;
    static final int yOffset = 30;
    public static jalview.ws.Discoverer discoverer;
    /**
     * Creates a new Desktop object.
     */
    public Desktop()
    {
        Image image = null;

        try
        {
            java.net.URL url = getClass().getResource("/images/logo.gif");

            if (url != null)
            {
                image = java.awt.Toolkit.getDefaultToolkit().createImage(url);

                MediaTracker mt = new MediaTracker(this);
                mt.addImage(image, 0);
                mt.waitForID(0);
                setIconImage(image);
            }
        }
        catch (Exception ex)
        {
        }

        setTitle("Jalview 2005");
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        desktop = new JDesktopPane();
        desktop.setBackground(Color.white);
        setContentPane(desktop);
        desktop.setDragMode(JDesktopPane.OUTLINE_DRAG_MODE);

        // This line prevents Windows Look&Feel resizing all new windows to maximum
        // if previous window was maximised
        desktop.setDesktopManager(new DefaultDesktopManager());

        Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        String x = jalview.bin.Cache.getProperty("SCREEN_X");
        String y = jalview.bin.Cache.getProperty("SCREEN_Y");
        String width = jalview.bin.Cache.getProperty("SCREEN_WIDTH");
        String height = jalview.bin.Cache.getProperty("SCREEN_HEIGHT");

        if ((x != null) && (y != null) && (width != null) && (height != null))
        {
            setBounds(Integer.parseInt(x), Integer.parseInt(y),
                Integer.parseInt(width), Integer.parseInt(height));
        }
        else
        {
            setBounds((int) (screenSize.width - 900) / 2,
                (int) (screenSize.height - 650) / 2, 900, 650);
        }

        this.addWindowListener(new WindowAdapter()
            {
                public void windowClosing(WindowEvent evt)
                {
                    quit();
                }
            });

        this.setDropTarget(new java.awt.dnd.DropTarget(desktop, this));

        /////////Add a splashscreen on startup
        /////////Add a splashscreen on startup
        JInternalFrame frame = new JInternalFrame();

        SplashScreen splash = new SplashScreen(frame, image);
        frame.setContentPane(splash);
        frame.setLayer(JLayeredPane.PALETTE_LAYER);
        frame.setLocation((int) ((getWidth() - 750) / 2),
            (int) ((getHeight() - 160) / 2));

        addInternalFrame(frame, "", 750, 160, false);

        discoverer=new jalview.ws.Discoverer(); // Only gets started if gui is displayed.

    }

    /**
     * DOCUMENT ME!
     *
     * @param frame DOCUMENT ME!
     * @param title DOCUMENT ME!
     * @param w DOCUMENT ME!
     * @param h DOCUMENT ME!
     */
    public static synchronized void addInternalFrame(final JInternalFrame frame,
        String title, int w, int h)
    {
        addInternalFrame(frame, title, w, h, true);
    }

    /**
     * DOCUMENT ME!
     *
     * @param frame DOCUMENT ME!
     * @param title DOCUMENT ME!
     * @param w DOCUMENT ME!
     * @param h DOCUMENT ME!
     * @param resizable DOCUMENT ME!
     */
    public static synchronized void addInternalFrame(final JInternalFrame frame,
        String title, int w, int h, boolean resizable)
    {

      frame.setTitle(title);
      if(frame.getWidth()<1 || frame.getHeight()<1)
      {
        frame.setSize(w, h);
      }
      // THIS IS A PUBLIC STATIC METHOD, SO IT MAY BE CALLED EVEN IN
      // A HEADLESS STATE WHEN NO DESKTOP EXISTS. MUST RETURN
      // IF JALVIEW IS RUNNING HEADLESS
      /////////////////////////////////////////////////
      if (System.getProperty("java.awt.headless") != null
          && System.getProperty("java.awt.headless").equals("true"))
      {
        return;
      }


        openFrameCount++;

        frame.setVisible(true);
        frame.setClosable(true);
        frame.setResizable(resizable);
        frame.setMaximizable(resizable);
        frame.setIconifiable(resizable);
        frame.setFrameIcon(null);

        if (frame.getX()<1 && frame.getY()<1)
       {
         frame.setLocation(xOffset * openFrameCount, yOffset * ((openFrameCount-1)%10)+yOffset);
       }

        final JMenuItem menuItem = new JMenuItem(title);
        frame.addInternalFrameListener(new javax.swing.event.InternalFrameAdapter()
            {
                public void internalFrameClosed(
                    javax.swing.event.InternalFrameEvent evt)
                {
                    openFrameCount--;
                    windowMenu.remove(menuItem);
                }
                ;
            });

        menuItem.addActionListener(new ActionListener()
            {
                public void actionPerformed(ActionEvent e)
                {
                    try
                    {
                        frame.setSelected(true);
                        frame.setIcon(false);
                    }
                    catch (java.beans.PropertyVetoException ex)
                    {

                    }
                }
            });

        windowMenu.add(menuItem);

        desktop.add(frame);
        frame.toFront();
        try{
          frame.setSelected(true);
        }catch(java.beans.PropertyVetoException ve)
        {}
    }

    /**
     * DOCUMENT ME!
     *
     * @param evt DOCUMENT ME!
     */
    public void dragEnter(DropTargetDragEvent evt)
    {
    }

    /**
     * DOCUMENT ME!
     *
     * @param evt DOCUMENT ME!
     */
    public void dragExit(DropTargetEvent evt)
    {
    }

    /**
     * DOCUMENT ME!
     *
     * @param evt DOCUMENT ME!
     */
    public void dragOver(DropTargetDragEvent evt)
    {
    }

    /**
     * DOCUMENT ME!
     *
     * @param evt DOCUMENT ME!
     */
    public void dropActionChanged(DropTargetDragEvent evt)
    {
    }

    /**
     * DOCUMENT ME!
     *
     * @param evt DOCUMENT ME!
     */
    public void drop(DropTargetDropEvent evt)
    {
        Transferable t = evt.getTransferable();

        if (!t.isDataFlavorSupported(DataFlavor.javaFileListFlavor))
        {
            return;
        }

        evt.acceptDrop(DnDConstants.ACTION_COPY_OR_MOVE);

        try
        {
            java.util.List files = (java.util.List) t.getTransferData(DataFlavor.javaFileListFlavor);

            for (int i = 0; i < files.size(); i++)
            {
                String file = files.get(i).toString();
                String protocol = "File";
                String format = null;

                if (file.endsWith(".jar"))
                {
                  format = "Jalview";

                }
                else
                {
                    format = jalview.io.IdentifyFile.Identify(file,
                            protocol);
                }
                LoadFile(file, protocol, format);
            }
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void inputLocalFileMenuItem_actionPerformed(ActionEvent e)
    {
        JalviewFileChooser chooser = new JalviewFileChooser(jalview.bin.Cache.getProperty(
                    "LAST_DIRECTORY"),
                new String[]
                {
                    "fa, fasta, fastq", "aln", "pfam", "msf", "pir", "blc",
                    "jar"
                },
                new String[]
                {
                    "Fasta", "Clustal", "PFAM", "MSF", "PIR", "BLC", "Jalview"
                }, jalview.bin.Cache.getProperty("DEFAULT_FILE_FORMAT"));

        chooser.setFileView(new JalviewFileView());
        chooser.setDialogTitle("Open local file");
        chooser.setToolTipText("Open");

        int value = chooser.showOpenDialog(this);

        if (value == JalviewFileChooser.APPROVE_OPTION)
        {
            String choice = chooser.getSelectedFile().getPath();
            jalview.bin.Cache.setProperty("LAST_DIRECTORY",
                chooser.getSelectedFile().getParent());

            String format = null;
            if (chooser.getSelectedFormat().equals("Jalview"))
            {
              format = "Jalview";
            }
            else
            {
                format = IdentifyFile.Identify(choice, "File");
            }

            jalview.bin.Cache.setProperty("DEFAULT_FILE_FORMAT", format);
            LoadFile(choice, "File", format);
        }
    }

    /**
     * DOCUMENT ME!
     *
     * @param file DOCUMENT ME!
     * @param protocol DOCUMENT ME!
     * @param format DOCUMENT ME!
     */
    public void LoadFile(String file, String protocol, String format)
    {
      FileLoader fileLoader = new FileLoader();
      fileLoader.LoadFile(file, protocol, format);
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void inputURLMenuItem_actionPerformed(ActionEvent e)
    {
        String url = JOptionPane.showInternalInputDialog(Desktop.desktop,
                "Enter url of input file", "Input alignment from URL",
                JOptionPane.QUESTION_MESSAGE, null, null, "http://www.")
                                .toString();

        if (url == null)
        {
            return;
        }

        if (url.trim().toLowerCase().endsWith(".jar"))
        {
               jalview.bin.Cache.setProperty("DEFAULT_FILE_FORMAT", "Jalview");
               Jalview2XML.LoadJalviewAlign(url);
        }
        else
        {

          String format = IdentifyFile.Identify(url, "URL");

          if (format.equals("URL NOT FOUND"))
          {
            JOptionPane.showInternalMessageDialog(Desktop.desktop,
                                                  "Couldn't locate " + url,
                                                  "URL not found",
                                                  JOptionPane.WARNING_MESSAGE);

            return;
          }

          LoadFile(url, "URL", format);
        }
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void inputTextboxMenuItem_actionPerformed(ActionEvent e)
    {
        CutAndPasteTransfer cap = new CutAndPasteTransfer();
        cap.setForInput();
        Desktop.addInternalFrame(cap, "Cut & Paste Alignment File", 600, 500);
    }

    /*
     * Exit the program
     */
    public void quit()
    {
        jalview.bin.Cache.setProperty("SCREEN_X", getBounds().x + "");
        jalview.bin.Cache.setProperty("SCREEN_Y", getBounds().y + "");
        jalview.bin.Cache.setProperty("SCREEN_WIDTH", getWidth() + "");
        jalview.bin.Cache.setProperty("SCREEN_HEIGHT", getHeight() + "");
        System.exit(0);
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void aboutMenuItem_actionPerformed(ActionEvent e)
    {
      StringBuffer message = new StringBuffer("JalView 2005 version " +
                                              jalview.bin.Cache.getProperty(
          "VERSION") +
                                              "; last updated: " +
                                              jalview.bin.
                                              Cache.getDefault("BUILD_DATE", "unknown"));

      if (!jalview.bin.Cache.getProperty("LATEST_VERSION").equals(
          jalview.bin.Cache.getProperty("VERSION")))
      {
        message.append("\n\n!! Jalview version "
                       + jalview.bin.Cache.getProperty("LATEST_VERSION")
                       + " is available for download from http://www.jalview.org !!\n");

      }

      message.append( "\nAuthors:  Michele Clamp, James Cuff, Steve Searle, Andrew Waterhouse, Jim Procter & Geoff Barton." +
            "\nCurrent development managed by Andrew Waterhouse; Barton Group, University of Dundee." +
            "\nFor all issues relating to Jalview, email help@jalview.org" +
            "\n\nIf  you use JalView, please cite:" +
            "\n\"Clamp, M., Cuff, J., Searle, S. M. and Barton, G. J. (2004), The Jalview Java Alignment Editor\"" +
            "\nBioinformatics,  2004 12;426-7.");

        JOptionPane.showInternalMessageDialog(Desktop.desktop,

           message.toString(), "About Jalview",
            JOptionPane.INFORMATION_MESSAGE);
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void documentationMenuItem_actionPerformed(ActionEvent e)
    {
        try
        {
            ClassLoader cl = jalview.gui.Desktop.class.getClassLoader();
            java.net.URL url = javax.help.HelpSet.findHelpSet(cl, "help/help");
            javax.help.HelpSet hs = new javax.help.HelpSet(cl, url);

            javax.help.HelpBroker hb = hs.createHelpBroker();
            hb.setLocation(new Point(200, 50));
            hb.setSize(new Dimension(800, 700));
            hb.setCurrentID("home");
            hb.setDisplayed(true);
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    protected void preferences_actionPerformed(ActionEvent e)
    {
        new Preferences();
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void saveState_actionPerformed(ActionEvent e)
    {
        JalviewFileChooser chooser = new JalviewFileChooser(jalview.bin.Cache.getProperty(
                    "LAST_DIRECTORY"), new String[] { "jar" },
                new String[] { "Jalview Project" }, "Jalview Project");

        chooser.setFileView(new JalviewFileView());
        chooser.setDialogTitle("Save State");

        int value = chooser.showSaveDialog(this);

        if (value == JalviewFileChooser.APPROVE_OPTION)
        {
            java.io.File choice = chooser.getSelectedFile();
            jalview.bin.Cache.setProperty("LAST_DIRECTORY", choice.getParent());
            Jalview2XML.SaveState(choice);
        }
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void loadState_actionPerformed(ActionEvent e)
    {
        JalviewFileChooser chooser = new JalviewFileChooser(jalview.bin.Cache.getProperty(
                    "LAST_DIRECTORY"), new String[] { "jar" },
                new String[] { "Jalview Project" }, "Jalview Project");
        chooser.setFileView(new JalviewFileView());
        chooser.setDialogTitle("Restore state");

        int value = chooser.showOpenDialog(this);

        if (value == JalviewFileChooser.APPROVE_OPTION)
        {
            String choice = chooser.getSelectedFile().getAbsolutePath();
            jalview.bin.Cache.setProperty("LAST_DIRECTORY",
                chooser.getSelectedFile().getParent());
            Jalview2XML.LoadJalviewAlign(choice);
        }
    }

}

==> jalview_2_07.tar.gz: jalview/src/jalview/gui/Desktop.java <==
/*
 * Jalview - A Sequence Alignment Editor and Viewer
 * Copyright (C) 2005 AM Waterhouse, J Procter, G Barton, M Clamp, S Searle
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package jalview.gui;

import jalview.io.*;

import java.awt.*;
import java.awt.datatransfer.*;
import java.awt.dnd.*;
import java.awt.event.*;

import javax.swing.*;


/**
 * DOCUMENT ME!
 *
 * @author $author$
 * @version $Revision: 1.68 $
 */
public class Desktop extends jalview.jbgui.GDesktop
    implements DropTargetListener
{
    /** DOCUMENT ME!! */
    public static JDesktopPane desktop;
    static int openFrameCount = 0;
    static final int xOffset = 30;
    static final int yOffset = 30;
    public static jalview.ws.Discoverer discoverer;

    public static Object [] jalviewClipboard;


    /**
     * Creates a new Desktop object.
     */
    public Desktop()
    {
        Image image = null;


        try
        {
            java.net.URL url = getClass().getResource("/images/logo.gif");

            if (url != null)
            {
                image = java.awt.Toolkit.getDefaultToolkit().createImage(url);

                MediaTracker mt = new MediaTracker(this);
                mt.addImage(image, 0);
                mt.waitForID(0);
                setIconImage(image);
            }
        }
        catch (Exception ex)
        {
        }

        setTitle("Jalview "+jalview.bin.Cache.getProperty("VERSION"));
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        desktop = new JDesktopPane();
        desktop.setBackground(Color.white);
        setContentPane(desktop);
        desktop.setDragMode(JDesktopPane.OUTLINE_DRAG_MODE);

        // This line prevents Windows Look&Feel resizing all new windows to maximum
        // if previous window was maximised
        desktop.setDesktopManager(new DefaultDesktopManager());

        Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        String x = jalview.bin.Cache.getProperty("SCREEN_X");
        String y = jalview.bin.Cache.getProperty("SCREEN_Y");
        String width = jalview.bin.Cache.getProperty("SCREEN_WIDTH");
        String height = jalview.bin.Cache.getProperty("SCREEN_HEIGHT");

        if ((x != null) && (y != null) && (width != null) && (height != null))
        {
            setBounds(Integer.parseInt(x), Integer.parseInt(y),
                Integer.parseInt(width), Integer.parseInt(height));
        }
        else
        {
            setBounds((int) (screenSize.width - 900) / 2,
                (int) (screenSize.height - 650) / 2, 900, 650);
        }

        this.addWindowListener(new WindowAdapter()
            {
                public void windowClosing(WindowEvent evt)
                {
                    quit();
                }
            });

        this.setDropTarget(new java.awt.dnd.DropTarget(desktop, this));

        /////////Add a splashscreen on startup
        /////////Add a splashscreen on startup
        JInternalFrame frame = new JInternalFrame();

        SplashScreen splash = new SplashScreen(frame, image);
        frame.setContentPane(splash);
        frame.setLayer(JLayeredPane.PALETTE_LAYER);
        frame.setLocation((int) ((getWidth() - 750) / 2),
            (int) ((getHeight() - 160) / 2));

        addInternalFrame(frame, "", 750, 160, false);

        discoverer=new jalview.ws.Discoverer(); // Only gets started if gui is displayed.

    }

    /**
     * DOCUMENT ME!
     *
     * @param frame DOCUMENT ME!
     * @param title DOCUMENT ME!
     * @param w DOCUMENT ME!
     * @param h DOCUMENT ME!
     */
    public static synchronized void addInternalFrame(final JInternalFrame frame,
        String title, int w, int h)
    {
        addInternalFrame(frame, title, w, h, true);
    }

    /**
     * DOCUMENT ME!
     *
     * @param frame DOCUMENT ME!
     * @param title DOCUMENT ME!
     * @param w DOCUMENT ME!
     * @param h DOCUMENT ME!
     * @param resizable DOCUMENT ME!
     */
    public static synchronized void addInternalFrame(final JInternalFrame frame,
        String title, int w, int h, boolean resizable)
    {

      frame.setTitle(title);
      if(frame.getWidth()<1 || frame.getHeight()<1)
      {
        frame.setSize(w, h);
      }
      // THIS IS A PUBLIC STATIC METHOD, SO IT MAY BE CALLED EVEN IN
      // A HEADLESS STATE WHEN NO DESKTOP EXISTS. MUST RETURN
      // IF JALVIEW IS RUNNING HEADLESS
      /////////////////////////////////////////////////
      if (System.getProperty("java.awt.headless") != null
          && System.getProperty("java.awt.headless").equals("true"))
      {
        return;
      }


        openFrameCount++;

        frame.setVisible(true);
        frame.setClosable(true);
        frame.setResizable(resizable);
        frame.setMaximizable(resizable);
        frame.setIconifiable(resizable);
        frame.setFrameIcon(null);

        if (frame.getX()<1 && frame.getY()<1)
       {
         frame.setLocation(xOffset * openFrameCount, yOffset * ((openFrameCount-1)%10)+yOffset);
       }

        final JMenuItem menuItem = new JMenuItem(title);
        frame.addInternalFrameListener(new javax.swing.event.InternalFrameAdapter()
            {
              public void internalFrameActivated(javax.swing.event.
                                                 InternalFrameEvent evt)
              {
                JInternalFrame itf = desktop.getSelectedFrame();
                if (itf != null)
                  itf.requestFocus();

              }

                public void internalFrameClosed(
                    javax.swing.event.InternalFrameEvent evt)
                {
                    openFrameCount--;
                    windowMenu.remove(menuItem);
                    JInternalFrame itf = desktop.getSelectedFrame();
                       if (itf != null)
                        itf.requestFocus();
                }
                ;
            });

        menuItem.addActionListener(new ActionListener()
            {
                public void actionPerformed(ActionEvent e)
                {
                    try
                    {
                        frame.setSelected(true);
                        frame.setIcon(false);
                    }
                    catch (java.beans.PropertyVetoException ex)
                    {

                    }
                }
            });

        windowMenu.add(menuItem);

        desktop.add(frame);
        frame.toFront();
        try{
          frame.setSelected(true);
          frame.requestFocus();
        }catch(java.beans.PropertyVetoException ve)
        {}
    }


    /**
     * DOCUMENT ME!
     *
     * @param evt DOCUMENT ME!
     */
    public void dragEnter(DropTargetDragEvent evt)
    {
    }

    /**
     * DOCUMENT ME!
     *
     * @param evt DOCUMENT ME!
     */
    public void dragExit(DropTargetEvent evt)
    {
    }

    /**
     * DOCUMENT ME!
     *
     * @param evt DOCUMENT ME!
     */
    public void dragOver(DropTargetDragEvent evt)
    {
    }

    /**
     * DOCUMENT ME!
     *
     * @param evt DOCUMENT ME!
     */
    public void dropActionChanged(DropTargetDragEvent evt)
    {
    }

    /**
     * DOCUMENT ME!
     *
     * @param evt DOCUMENT ME!
     */
    public void drop(DropTargetDropEvent evt)
    {
        Transferable t = evt.getTransferable();

        if (!t.isDataFlavorSupported(DataFlavor.javaFileListFlavor))
        {
            return;
        }

        evt.acceptDrop(DnDConstants.ACTION_COPY_OR_MOVE);

        try
        {
            java.util.List files = (java.util.List) t.getTransferData(DataFlavor.javaFileListFlavor);

            for (int i = 0; i < files.size(); i++)
            {
                String file = files.get(i).toString();
                String protocol = "File";
                String format = null;

                if (file.endsWith(".jar"))
                {
                  format = "Jalview";

                }
                else
                {
                    format = jalview.io.IdentifyFile.Identify(file,
                            protocol);
                }
                LoadFile(file, protocol, format);
            }
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void inputLocalFileMenuItem_actionPerformed(ActionEvent e)
    {
        JalviewFileChooser chooser = new JalviewFileChooser(jalview.bin.Cache.getProperty(
                    "LAST_DIRECTORY"),
                new String[]
                {
                    "fa, fasta, fastq", "aln", "pfam", "msf", "pir", "blc",
                    "jar"
                },
                new String[]
                {
                    "Fasta", "Clustal", "PFAM", "MSF", "PIR", "BLC", "Jalview"
                }, jalview.bin.Cache.getProperty("DEFAULT_FILE_FORMAT"));

        chooser.setFileView(new JalviewFileView());
        chooser.setDialogTitle("Open local file");
        chooser.setToolTipText("Open");

        int value = chooser.showOpenDialog(this);

        if (value == JalviewFileChooser.APPROVE_OPTION)
        {
            String choice = chooser.getSelectedFile().getPath();
            jalview.bin.Cache.setProperty("LAST_DIRECTORY",
                chooser.getSelectedFile().getParent());

            String format = null;
            if (chooser.getSelectedFormat().equals("Jalview"))
            {
              format = "Jalview";
            }
            else
            {
                format = IdentifyFile.Identify(choice, "File");
            }

            jalview.bin.Cache.setProperty("DEFAULT_FILE_FORMAT", format);
            LoadFile(choice, "File", format);
        }
    }

    /**
     * DOCUMENT ME!
     *
     * @param file DOCUMENT ME!
     * @param protocol DOCUMENT ME!
     * @param format DOCUMENT ME!
     */
    public void LoadFile(String file, String protocol, String format)
    {
      FileLoader fileLoader = new FileLoader();
      fileLoader.LoadFile(file, protocol, format);
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void inputURLMenuItem_actionPerformed(ActionEvent e)
    {
        Object reply = JOptionPane.showInternalInputDialog(Desktop.desktop,
                "Enter url of input file", "Input alignment from URL",
                JOptionPane.QUESTION_MESSAGE, null, null, "http://www.");

        if (reply == null)
        {
            return;
        }

        String url = reply.toString().trim();

        if (url.toLowerCase().endsWith(".jar"))
        {
               jalview.bin.Cache.setProperty("DEFAULT_FILE_FORMAT", "Jalview");
               Jalview2XML.LoadJalviewAlign(url);
        }
        else
        {

          String format = IdentifyFile.Identify(url, "URL");

          if (format.equals("URL NOT FOUND"))
          {
            JOptionPane.showInternalMessageDialog(Desktop.desktop,
                                                  "Couldn't locate " + url,
                                                  "URL not found",
                                                  JOptionPane.WARNING_MESSAGE);

            return;
          }

          LoadFile(url, "URL", format);
        }
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void inputTextboxMenuItem_actionPerformed(ActionEvent e)
    {
        CutAndPasteTransfer cap = new CutAndPasteTransfer();
        cap.setForInput();
        Desktop.addInternalFrame(cap, "Cut & Paste Alignment File", 600, 500);
    }

    /*
     * Exit the program
     */
    public void quit()
    {
        jalview.bin.Cache.setProperty("SCREEN_X", getBounds().x + "");
        jalview.bin.Cache.setProperty("SCREEN_Y", getBounds().y + "");
        jalview.bin.Cache.setProperty("SCREEN_WIDTH", getWidth() + "");
        jalview.bin.Cache.setProperty("SCREEN_HEIGHT", getHeight() + "");
        System.exit(0);
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void aboutMenuItem_actionPerformed(ActionEvent e)
    {
      StringBuffer message = new StringBuffer("JalView version " +
                                              jalview.bin.Cache.getProperty(
          "VERSION") +
                                              "; last updated: " +
                                              jalview.bin.
                                              Cache.getDefault("BUILD_DATE", "unknown"));

      if (!jalview.bin.Cache.getProperty("LATEST_VERSION").equals(
          jalview.bin.Cache.getProperty("VERSION")))
      {
        message.append("\n\n!! Jalview version "
                       + jalview.bin.Cache.getProperty("LATEST_VERSION")
                       + " is available for download from http://www.jalview.org !!\n");

      }

      message.append( "\nAuthors:  Michele Clamp, James Cuff, Steve Searle, Andrew Waterhouse, Jim Procter & Geoff Barton." +
            "\nCurrent development managed by Andrew Waterhouse; Barton Group, University of Dundee." +
            "\nFor all issues relating to Jalview, email help@jalview.org" +
            "\n\nIf  you use JalView, please cite:" +
            "\n\"Clamp, M., Cuff, J., Searle, S. M. and Barton, G. J. (2004), The Jalview Java Alignment Editor\"" +
            "\nBioinformatics,  2004 12;426-7.");

        JOptionPane.showInternalMessageDialog(Desktop.desktop,

           message.toString(), "About Jalview",
            JOptionPane.INFORMATION_MESSAGE);
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void documentationMenuItem_actionPerformed(ActionEvent e)
    {
        try
        {
            ClassLoader cl = jalview.gui.Desktop.class.getClassLoader();
            java.net.URL url = javax.help.HelpSet.findHelpSet(cl, "help/help");
            javax.help.HelpSet hs = new javax.help.HelpSet(cl, url);

            javax.help.HelpBroker hb = hs.createHelpBroker();
            hb.setCurrentID("home");
            hb.setDisplayed(true);
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    protected void preferences_actionPerformed(ActionEvent e)
    {
        new Preferences();
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void saveState_actionPerformed(ActionEvent e)
    {
        JalviewFileChooser chooser = new JalviewFileChooser(jalview.bin.Cache.getProperty(
                    "LAST_DIRECTORY"), new String[] { "jar" },
                new String[] { "Jalview Project" }, "Jalview Project");

        chooser.setFileView(new JalviewFileView());
        chooser.setDialogTitle("Save State");

        int value = chooser.showSaveDialog(this);

        if (value == JalviewFileChooser.APPROVE_OPTION)
        {
            java.io.File choice = chooser.getSelectedFile();
            jalview.bin.Cache.setProperty("LAST_DIRECTORY", choice.getParent());
            Jalview2XML.SaveState(choice);
        }
    }

    /**
     * DOCUMENT ME!
     *
     * @param e DOCUMENT ME!
     */
    public void loadState_actionPerformed(ActionEvent e)
    {
        JalviewFileChooser chooser = new JalviewFileChooser(jalview.bin.Cache.getProperty(
                    "LAST_DIRECTORY"), new String[] { "jar" },
                new String[] { "Jalview Project" }, "Jalview Project");
        chooser.setFileView(new JalviewFileView());
        chooser.setDialogTitle("Restore state");

        int value = chooser.showOpenDialog(this);

        if (value == JalviewFileChooser.APPROVE_OPTION)
        {
            String choice = chooser.getSelectedFile().getAbsolutePath();
            jalview.bin.Cache.setProperty("LAST_DIRECTORY",
                chooser.getSelectedFile().getParent());
            Jalview2XML.LoadJalviewAlign(choice);
        }
    }

  /*  public void vamsasLoad_actionPerformed(ActionEvent e)
    {
      JalviewFileChooser chooser = new JalviewFileChooser(jalview.bin.Cache.
          getProperty("LAST_DIRECTORY"));

      chooser.setFileView(new JalviewFileView());
      chooser.setDialogTitle("Load Vamsas file");
      chooser.setToolTipText("Import");

      int value = chooser.showOpenDialog(this);

      if (value == JalviewFileChooser.APPROVE_OPTION)
      {
        jalview.io.VamsasDatastore vs = new jalview.io.VamsasDatastore(null);
        vs.load(
            chooser.getSelectedFile().getAbsolutePath()
            );
      }

    }*/


    public void inputSequence_actionPerformed(ActionEvent e)
    {
      SequenceFetcher sf = new SequenceFetcher(null);
    }
}
